@@ -69,13 +69,11 @@ our @EXPORT = qw(
 	notnum precess round 
 	d2hms d2dms d2dm dms2d hms2d
 	dd2nex dd2pnex nex2dd pnex2dd
-
-	get_model_name
-
+	
 	open_telescope_port 
 	close_telescope_port
 	read_telescope 
-
+	
 	tc_check_align
 	tc_goto_rade tc_goto_rade_p
 	tc_goto_azalt tc_goto_azalt_p
@@ -91,12 +89,12 @@ our @EXPORT = qw(
 	tc_set_time tc_set_location
 	tc_get_tracking_mode tc_set_tracking_mode
 	tc_slew_variable tc_slew_fixed
-
+	
 	TC_TRACK_OFF
 	TC_TRACK_ALT_AZ
 	TC_TRACK_EQ_NORTH
 	TC_REACK_EQ_SOUTH
-
+	
 	TC_DIR_POSITIVE
 	TC_DIR_NEGATIVE
 
@@ -104,7 +102,7 @@ our @EXPORT = qw(
 	TC_AXIS_DE_ALT	
 );
 
-our $VERSION = "0.06_1";
+our $VERSION = "0.01";
 
 use constant {
 	TC_TRACK_OFF => 0,
@@ -128,20 +126,6 @@ use constant {
 	RAD2DEG => 180.0/3.1415926535897932384626433832795
 };
 
-my %mounts = (
-	1 => "NexStar GPS Series",
-	3 => "NexStar i-Series",
-	4 => "NexStar i-Series SE",
-	5 => "CGE",
-	6 => "Advanced GT",
-	7 => "SLT",
-	9 => "CPC",
-	10 => "GT",
-	11 => "NexStar 4/5 SE",
-	12 => "NexStar 6/8 SE",
-	20 => "Advanced VX"
-);
-
 =head1 TESCOPE COMMUNICATION
 
 =over 8
@@ -160,34 +144,28 @@ sub open_telescope_port($) {
 	$port->baudrate(9600); 
 	$port->parity("none"); 
 	$port->databits(8); 
-	$port->stopbits(1); 
-	$port->datatype('raw');    
+	$port->stopbits(1);  
 	$port->write_settings;
 	$port->read_char_time(0);     # don't wait for each character
 	$port->read_const_time(4000); # 4 second per unfulfilled "read" call
 	return $port;
 }
 
-=item read_telescope(port, len)
+=item read_telescope(port)
 
-Reads data from the telescope. On error or in case less than len bytes are
-read undef is returned.
+Reads data from the telescope. In case nothing is read undef is returned.
 
 =cut
-sub read_telescope($$) {
-	my ($port,$len) = @_;
+sub read_telescope($) {
+	my ($port) = @_;
 	my $response;
 	my $char;
 	my $count;
-	my $total=0;
 	do {
 		($count,$char)=$port->read(1);
 		if ($count == 0) { return undef; }
-		$total += $count;
 		$response .= $char;
-	} while ($total < $len);
-	
-	if ($char ne "#") { return undef; }
+	} while ($char ne "#");
 	return $response;
 }
 
@@ -235,7 +213,7 @@ sub tc_check_align($) {
 	my ($port) = @_;
 
 	$port->write("J");
-	my $response = read_telescope($port,2);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return ord(substr($response, 0, 1));
 	} else {
@@ -269,7 +247,7 @@ sub tc_goto_rade {
 		$nex=dd2nex($ra, $de);
 		$port->write("R".$nex);
 	}
-	my $response = read_telescope($port,1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -306,7 +284,7 @@ sub tc_goto_azalt {
 		$nex=dd2nex($az, $alt);
 		$port->write("B".$nex);
 	}
-	my $response = read_telescope($port,1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -329,22 +307,22 @@ tc_get_rade_p uses precise GET. If no response received undef is returned.
 sub tc_get_rade {
 	my ($port, $precise) = @_;
 	
+	if((defined $precise) and ($precise =! 0)) {
+		$port->write("e");
+	} else {
+		$port->write("E");
+	}
+	my $response = read_telescope($port);
+	if (! defined $response) {
+		return undef;
+	} 
+	
 	my $ra;
 	my $de;
 	
 	if((defined $precise) and ($precise =! 0)) {
-		$port->write("e");
-		my $response = read_telescope($port, 18);
-		if (! defined $response) {
-			return undef;
-		} 
 		($ra,$de) = pnex2dd($response);
 	} else {
-		$port->write("E");
-		my $response = read_telescope($port, 10);
-		if (! defined $response) {
-			return undef;
-		} 
 		($ra,$de) = nex2dd($response);
 	}
 	
@@ -366,22 +344,22 @@ tc_get_azalt_p uses precise GET. If no response received undef is returned.
 sub tc_get_azalt {
 	my ($port, $precise) = @_;
 	
+	if((defined $precise) and ($precise =! 0)) {
+		$port->write("z");
+	} else {
+		$port->write("Z");
+	}
+	my $response = read_telescope($port);
+	if (! defined $response) {
+		return undef;
+	} 
+	
 	my $az;
 	my $alt;
 	
 	if((defined $precise) and ($precise =! 0)) {
-		$port->write("z");
-		my $response = read_telescope($port, 18);
-		if (! defined $response) {
-			return undef;
-		} 
 		($az,$alt) = pnex2dd($response);
 	} else {
-		$port->write("Z");
-		my $response = read_telescope($port, 10);
-		if (! defined $response) {
-			return undef;
-		} 
 		($az,$alt) = nex2dd($response);
 	}
 	
@@ -417,7 +395,7 @@ sub tc_sync_rade {
 		$nex=dd2nex($ra, $de);
 		$port->write("S".$nex);
 	}
-	my $response = read_telescope($port, 1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -438,7 +416,7 @@ sub tc_goto_in_progress($) {
 	my ($port) = @_;
 
 	$port->write("L");
-	my $response = read_telescope($port, 2);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return substr($response, 0, 1);
 	} else {
@@ -455,7 +433,7 @@ sub tc_goto_cancel($) {
 	my ($port) = @_;
 		        
 	$port->write("M");
-	my $response = read_telescope($port, 1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -473,7 +451,7 @@ sub tc_echo($$) {
 	my ($port, $char) = @_;
 
 	$port->write("K".substr($char, 0, 1));
-	my $response = read_telescope($port, 2);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return substr($response, 0, 1);
 	} else {
@@ -491,7 +469,7 @@ sub tc_get_model($) {
 	my ($port) = @_;
 
 	$port->write("m");
-	my $response = read_telescope($port, 2);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return ord(substr($response, 0, 1));
 	} else {
@@ -509,7 +487,7 @@ sub tc_get_version($) {
 	my ($port) = @_;
 
 	$port->write("V");
-	my $response = read_telescope($port, 3);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return ord(substr($response, 0, 1)).
 			   ".".ord(substr($response, 1, 1));
@@ -535,7 +513,7 @@ sub tc_get_location {
 	my ($port,$str) = @_;
 
 	$port->write("w");
-	my $response = read_telescope($port, 9);
+	my $response = read_telescope($port);
 	if (! defined $response) {
 		return undef;
 	}
@@ -577,7 +555,7 @@ sub tc_get_location_str {
 	return tc_get_location(@_, 1);
 }
 
-=item tc_set_location(port,lon,lat)
+=item tc_get_location(port,lon,lat)
 
 This function sets the location coordinates lon, lat in decimal degrees. 
 Negative longitude is WEST. Negative latitude is SOUTH.
@@ -616,7 +594,7 @@ sub tc_set_location {
 	$port->write(chr($lons));
 	$port->write(chr($iswest));
 
-	my $response = read_telescope($port, 1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -629,7 +607,7 @@ sub tc_set_location {
 This function returns the stored time (in unixtime format), timezone (in hours) and daylight saving time(0|1).
 If no response received undef is returned. 
 
-=item tc_get_time_str(port)
+=item tc_get_location_str(port)
 
 This function returns the stored date, time (as strings), timezone (in hours) and daylight saving time(0|1).
 If no response received undef is returned.
@@ -640,7 +618,7 @@ sub tc_get_time {
 	my ($port,$str) = @_;
 
 	$port->write("h");
-	my $response = read_telescope($port, 9);
+	my $response = read_telescope($port);
 	if (! defined $response) {
 		return undef;
 	}
@@ -701,7 +679,7 @@ sub tc_set_time {
 	$port->write(chr($tz));
 	$port->write(chr($dst));
 
-	my $response = read_telescope($port, 1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -720,7 +698,7 @@ sub tc_get_tracking_mode($) {
 	my ($port) = @_;
 
 	$port->write("t");
-	my $response = read_telescope($port, 2);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return ord(substr($response, 0, 1));
 	} else {
@@ -744,7 +722,7 @@ sub tc_set_tracking_mode($$) {
 	}
 	$port->write("T");
 	$port->write(chr($mode));
-	my $response = read_telescope($port, 1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -793,7 +771,7 @@ sub tc_slew_fixed {
 	$port->write(chr(0));
 	$port->write(chr(0));
 	
-	my $response = read_telescope($port, 1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -827,13 +805,12 @@ sub tc_slew_variable {
 		$direction = _TC_DIR_NEGATIVE;
 	}
 	
-	$rate = int(4*$rate);
+	$rate = int($rate) * 4;
 	my $rateH = int($rate / 256);
 	my $rateL = $rate % 256;
-	print "RATEf : $rateH $rateL\n";
 
 	$port->write("P");
-	$port->write(chr(3));
+	$port->write(chr(2));
 	$port->write(chr($axis));
 	$port->write(chr($direction));
 	$port->write(chr($rateH));
@@ -841,7 +818,7 @@ sub tc_slew_variable {
 	$port->write(chr(0));
 	$port->write(chr(0));
 	
-	my $response = read_telescope($port, 1);
+	my $response = read_telescope($port);
 	if (defined $response) {
 		return 1;
 	} else {
@@ -849,18 +826,6 @@ sub tc_slew_variable {
 	}
 }
 
-=item get_model_name(model_id)
-
-Return the name of the mount by the id from tc_get_model().
-If the mount is not known undef is returned.
-
-=cut
-
-sub get_model_name($) {
-	my ($model_id) = @_;
-	return $mounts{$model_id};
-}
-
 =back
 
 =head1 UTILITY FUNCTIONS
@@ -1127,8 +1092,8 @@ sub nex2dd ($){
 	my $d2_factor = hex(substr($nexres, 5, 4)) / 65536;
 	my $d1 = 360 * $d1_factor; 
 	my $d2 = 360 * $d2_factor;
-	$d2 = $d2 + 360 if ($d2 < -90);
 	$d2 = $d2 - 360 if ($d2 > 90);
+	$d2 = $d2 + 360 if ($d2 < -90);
 
 	return($d1, $d2);
 }
@@ -1145,8 +1110,8 @@ sub pnex2dd ($){
 	my $d2_factor = hex(substr($nexres, 9, 8)) / 0xffffffff;
 	my $d1 = 360 * $d1_factor;
 	my $d2 = 360 * $d2_factor;
-	$d2 = $d2 + 360 if ($d2 < -90);
 	$d2 = $d2 - 360 if ($d2 > 90);
+	$d2 = $d2 + 360 if ($d2 < -90);
 
 	return($d1, $d2);
 }
