@@ -2,13 +2,9 @@
 use strict;
 use NexStarCtl;
 
-print "(0,".TC_AXIS_RA_AZM.",".TC_DIR_POSITIVE.",3)\n";
+print "(0,".TC_AXIS_RA_AZM.",".TC_DIR_POSITIVE.",3)";
 
 
-print get_model_name(1)."\n";
-print get_model_name(2)."\n";
-print get_model_name(19)."\n";
-
 my $port = open_telescope_port("/dev/cu.usbserial"); 
 
 if (!defined $port) {
@@ -32,62 +28,46 @@ print "LONs=$lon LATs=$lat\n";
 
 my $tm=time();
 print "$tm\n";
-#print "SETTIME= ".tc_set_time($port,$tm,2,1)."\n";
+#print "SETTIME= ".tc_set_time($port,$tm+60,2,1)."\n";
 
 my ($date,$time,$tz,$dst) = tc_get_time_str($port);
 
 print "$date, $time, $tz, $dst\n";
 
-
-#my $echo;
-#for (my $i=10; $i<256; $i++) {
-#	$echo = ord(tc_echo($port, chr($i)));
-#
-#	sleep 1;
-#	if ($echo != $i) {
-#		print "ERROR: Sent $i received $echo\n";
-#	} else {
-#		print "OK: Sent $i received $echo\n";
-#	}
-#	
-#}
-
 #print "GOTO = ".tc_goto_rade_p($port,11*15,21)."\n";
 
 #sleep(2);
 #print "GOTO Cancel = ".tc_goto_cancel($port)."\n";
 
-#print "TRACKING SET= ".tc_set_tracking_mode($port,0)."\n";
-#print "TRACKING = ".tc_get_tracking_mode($port)."\n";
+print "TRACKING SET= ".tc_set_tracking_mode($port,2)."\n";
+print "TRACKING = ".tc_get_tracking_mode($port)."\n";
 
-#tc_slew_variable($port,TC_AXIS_RA_AZM,TC_DIR_POSITIVE,15.25); 
+#tc_slew_fixed($port,TC_AXIS_RA_AZM,TC_DIR_POSITIVE,9); 
 #sleep(2);
-#tc_slew_variable($port,TC_AXIS_DE_ALT,TC_DIR_POSITIVE,1);
+#tc_slew_fixed($port,TC_AXIS_DE_ALT,TC_DIR_NEGATIVE,9);
 #sleep(2);
 #tc_slew_fixed($port,TC_AXIS_RA_AZM,TC_DIR_NEGATIVE,0);
 #sleep(2);
-#tc_slew_fixed($port,TC_AXIS_DE_ALT,TC_DIR_POSITIVE,0);
-
-#print "TRACKING = ".tc_get_tracking_mode($port)."\n";
+#tc_slew_fixed($port,TC_AXIS_DE_ALT,TC_DIR_NEGATIVE,0);
 
 #print "TRACKING SET= ".tc_set_tracking_mode($port,2)."\n";
-#print "TRACKING = ".tc_get_tracking_mode($port)."\n";
+print "TRACKING = ".tc_get_tracking_mode($port)."\n";
 
 
-#while (tc_goto_in_progress($port)) {
-#	sleep(1);
-#	print ".";
-#}
-#print "OK\n";
+while (tc_goto_in_progress($port)) {
+	sleep(1);
+	print ".";
+}
+print "OK\n";
 
 #print "SYNC = ".tc_sync_rade_p($port,0,0)."\n";
 
-#my ($rap,$decp) = tc_get_rade_p($port);
-#my ($ra,$dec) = tc_get_rade($port);
+my ($rap,$decp) = tc_get_rade_p($port);
+my ($ra,$dec) = tc_get_rade($port);
 
 
-#my ($azp,$altp) = tc_get_azalt_p($port);
-#my ($az,$alt) = tc_get_azalt($port);
+my ($azp,$altp) = tc_get_azalt_p($port);
+my ($az,$alt) = tc_get_azalt($port);
 
 close_telescope_port($port);
 
@@ -112,15 +92,15 @@ close_telescope_port($port);
 #my ($ra,$dec)=nex2dd($nex);
 #print "RA=$ra\nDE=$dec\n";
 
-#my $ras=d2hms($ra);
-#my $decs=d2dms($dec);
+my $ras=d2hms($ra);
+my $decs=d2dms($dec);
 
-#my $rasp=d2hms($rap);
-#my $decsp=d2dms($decp);
+my $rasp=d2hms($rap);
+my $decsp=d2dms($decp);
 
 
-#print "RA=$ras\nDEC=$decs\n";
-#print "RAp=$rasp\nDECp=$decsp\n";
+print "RA=$ras\nDEC=$decs\n";
+print "RAp=$rasp\nDECp=$decsp\n";
 
-#print "AZ=$az\nALT=$alt\n";
-#print "AZp=$azp\nALTp=$altp\n";
+print "AZ=$az\nALT=$alt\n";
+print "AZp=$azp\nALTp=$altp\n";
